@@ -3,7 +3,8 @@
 	
 	@author	Daniele Maio (b0unc3) 
 	@date	18/07/2010
-	@ver	0.5
+	@update	12/08/2010
+	@ver	0.6
 	
 */
 #include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
@@ -37,6 +38,7 @@ sort_iter_compare_func (GtkTreeModel *model,
 	gint ret = 0;
 
 
+
         gtk_tree_model_get(model, a, 0, &name1, -1);
         gtk_tree_model_get(model, b, 0, &name2, -1);
 
@@ -165,15 +167,27 @@ parse_settings(GConfClient* client)
 	
 }
 
+gboolean
+free_slot ( GtkWidget *btn, gpointer data )
+{
+	gint pos = (gint)data;
+	if ( gconf_client_unset (GCONF_CLIENT(client), g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[(gint)pos]), NULL ) ) {
+		names[pos] = "";
+		icons[pos] = "";
+		ossos[pos] = "";
+		bins[pos] = "";
+		hildon_button_set_image ( HILDON_BUTTON(btns[(gint)pos]), NULL );
+		hildon_button_set_text ( HILDON_BUTTON(btns[(gint)pos]), "Tap to set", "" );
+		hildon_banner_show_information(NULL, NULL, "Slot freed");
+		gtk_widget_hide ( GTK_WIDGET(gtk_widget_get_toplevel(btn)) );
+	} else hildon_banner_show_information(NULL,NULL, "Slot not freed");
+	
+	return FALSE;
+}
 gboolean
 set_shortcut ( HildonTouchSelector * selector, gint column, gpointer user_data )
 {
-/*
-	FILE *fd;
-	fd = fopen("/tmp/qldebug", "a+");
-	fprintf(fd,"here we go");
-	fclose(fd);
-	*/
+
 	//load icon from selected application
 	gchar *current_selection = NULL;
 	gint	pos;
@@ -189,22 +203,6 @@ set_shortcut ( HildonTouchSelector * selector, gint column, gpointer user_data )
 	pos = (gint)user_data;
 	
 	
-
-//	hildon_banner_show_information(NULL, NULL, g_strdup_printf("cs = %s",current_selection));
-	if ( current_selection != NULL && g_ascii_strncasecmp ("CLEAR SLOT",current_selection,-1) == 0 ) {
-		if ( gconf_client_unset (GCONF_CLIENT(client), g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[(gint)pos]), NULL ) ) {
-			names[pos] = "";
-			icons[pos] = "";
-			ossos[pos] = "";
-			bins[pos] = "";
-			hildon_button_set_image ( HILDON_BUTTON(btns[(gint)pos]), NULL );
-			hildon_button_set_text ( HILDON_BUTTON(btns[(gint)pos]), "Tap to set", "" );
-			hildon_banner_show_information(NULL, NULL, "Slot freed");
-		}
-		else hildon_banner_show_information(NULL,NULL, "Slot not freed");
-
-	}
-		
 	if ( current_selection != NULL ) {
 		it = gtk_icon_theme_new();
 		d = g_dir_open(APPS_DIR,0,NULL);
@@ -224,9 +222,8 @@ set_shortcut ( HildonTouchSelector * selector, gint column, gpointer user_data )
 						if ( g_key_file_has_key ( dsk, "Desktop Entry", "X-Text-Domain", &error ) ) {
 						//get name from gettext
 
-	//						bindtextdomain( "osso-sketch", LOCALES_DIR );//"/usr/share/locale" );
-							textdomain( g_key_file_get_value( dsk, "Desktop Entry", "X-Text-Domain", &error ) );//"osso-sketch" );
-							n = gettext( g_key_file_get_value ( dsk, "Desktop Entry", "Name", &error ) );//"sket_ap_sketch_title" ) );
+							textdomain( g_key_file_get_value( dsk, "Desktop Entry", "X-Text-Domain", &error ) );
+							n = gettext( g_key_file_get_value ( dsk, "Desktop Entry", "Name", &error ) );
 						} else if ( g_key_file_has_key ( dsk, "Desktop Entry", "Name", &error ) ) {
 							//get name from entry
 							n = g_key_file_get_value ( dsk, "Desktop Entry", "Name", &error );
@@ -268,14 +265,13 @@ set_shortcut ( HildonTouchSelector * selector, gint column, gpointer user_data )
 
 
 void 
-add_apps( HildonTouchSelector *btn)
+add_apps( HildonTouchSelector *btn, gpointer p)
 {
 	//load all available applications
 	GDir	*d;
 	GKeyFile *dsk;
 	GError *error;
 	
-	
 	d = g_dir_open(APPS_DIR,0,NULL);
 	if ( d ) {
 		setlocale( LC_ALL, "" );
@@ -293,9 +289,8 @@ add_apps( HildonTouchSelector *btn)
 					if ( g_key_file_has_key ( dsk, "Desktop Entry", "X-Text-Domain", &error ) ) {
 					//getname from gettext
 
-//						bindtextdomain( "osso-sketch", LOCALES_DIR );//"/usr/share/locale" );
-						textdomain( g_key_file_get_value( dsk, "Desktop Entry", "X-Text-Domain", &error ) );//"osso-sketch" );
-						n = gettext( g_key_file_get_value ( dsk, "Desktop Entry", "Name", &error ) );//"sket_ap_sketch_title" ) );
+						textdomain( g_key_file_get_value( dsk, "Desktop Entry", "X-Text-Domain", &error ) );
+						n = gettext( g_key_file_get_value ( dsk, "Desktop Entry", "Name", &error ) );
 					} else if ( g_key_file_has_key ( dsk, "Desktop Entry", "Name", &error ) ) {
 						n = g_key_file_get_value ( dsk, "Desktop Entry", "Name", &error );
 					}
@@ -310,7 +305,8 @@ add_apps( HildonTouchSelector *btn)
         g_dir_close(d);
         
 
-        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (btn), "CLEAR SLOT"); 
+         
+	hildon_touch_selector_set_live_search ( HILDON_TOUCH_SELECTOR(btn), TRUE );
         
         
  	GtkTreeModel *m;
@@ -321,6 +317,18 @@ add_apps( HildonTouchSelector *btn)
 	gtk_tree_sortable_set_sort_func(sortable, NULL, sort_iter_compare_func, NULL,NULL );
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(sortable), 0, GTK_SORT_ASCENDING);
 	hildon_touch_selector_set_model ( HILDON_TOUCH_SELECTOR(btn), 0, GTK_TREE_MODEL(sortable) );
+	GtkWidget *tmp;
+	GtkWidget *b;
+	
+	tmp = gtk_widget_get_toplevel (btn);
+	if ( GTK_IS_WIDGET (tmp)) {
+		b = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Clear Slot", "Click to free this slot");
+
+		gtk_box_pack_start ( GTK_BOX(tmp), b, FALSE,TRUE, 1);
+		g_signal_connect ( G_OBJECT(b), "clicked", G_CALLBACK(free_slot), (gpointer)p ); 
+		gtk_widget_show_all ( GTK_WIDGET(tmp) );
+	}	
+
 
 }
 
@@ -330,14 +338,9 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	GtkWidget 	*main_box;
 	GtkWidget	*conf_box;
 	GtkWidget	*action_box;
-//	GtkWidget	*clr_box;
 
 	GtkWidget	*sel1,*sel2,*sel3,*sel4;
-//	GtkWidget	*clr1,*clr2,*clr3,*clr4;
 	
-//	gint 		i;
-
-
 	program = HILDON_PROGRAM(hildon_program_get_instance());
 	g_set_application_name("Quick Launch - Configuration");
 
@@ -348,21 +351,8 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	
 	main_box = gtk_vbox_new ( FALSE,3 );
 	conf_box = gtk_hbox_new ( FALSE,0 );
-	//clr_box = gtk_hbox_new (FALSE,0 );
 	action_box = gtk_vbox_new ( FALSE,0 );
-	/*
-	for ( i=0; i<4; i++ ) {
-		btns[i] = hildon_picker_button_new(HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-		hildon_button_set_text ( HILDON_BUTTON(btns[i]), "Tap to set", "" );
-		gtk_widget_set_size_request ( GTK_WIDGET(btns[i]), 200,200 );
-		sel[i] = hildon_touch_selector_new_text();
-		add_apps(HILDON_TOUCH_SELECTOR(sel[i]));
-		clr[i] = hildon_check_button_new ( HILDON_SIZE_FINGER_HEIGHT );// hildon_button_new_with_text ( HILDON_SIZE_HALFSCREEN_WIDTH , HILDON_BUTTON_ARRANGEMENT_HORIZONTAL, "Clear", NULL);
-		gtk_button_set_label (GTK_BUTTON (clr[i]), "Clear");
-		hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[i]), HILDON_TOUCH_SELECTOR (sel[i]));
-		g_signal_connect ( G_OBJECT(sel[i]), "columns-changed", G_CALLBACK(set_shortcut), (gpointer)i );
-	}
-	*/
+	
 	btns[0] = hildon_picker_button_new(HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 	btns[1] = hildon_picker_button_new(HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 	btns[2] = hildon_picker_button_new(HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -380,41 +370,20 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	sel2 = hildon_touch_selector_new_text();
 	sel3 = hildon_touch_selector_new_text();
 	sel4 = hildon_touch_selector_new_text();
-	add_apps(HILDON_TOUCH_SELECTOR(sel1));
-	add_apps(HILDON_TOUCH_SELECTOR(sel2));
-	add_apps(HILDON_TOUCH_SELECTOR(sel3));
-	add_apps(HILDON_TOUCH_SELECTOR(sel4));	
-/*
-	clr1 = hildon_button_new_with_text ( HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Clear 1", NULL);
-	clr2 = hildon_button_new_with_text ( HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Clear 2", NULL);
-	clr3 = hildon_button_new_with_text ( HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Clear 3", NULL);
-	clr4 = hildon_button_new_with_text ( HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Clear 4", NULL);
-
-*/	
+	add_apps(HILDON_TOUCH_SELECTOR(sel1),(gpointer)0);
+	add_apps(HILDON_TOUCH_SELECTOR(sel2),(gpointer)1);
+	add_apps(HILDON_TOUCH_SELECTOR(sel3),(gpointer)2);
+	add_apps(HILDON_TOUCH_SELECTOR(sel4),(gpointer)3);	
+	
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[0]), HILDON_TOUCH_SELECTOR (sel1));
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[1]), HILDON_TOUCH_SELECTOR (sel2));
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[2]), HILDON_TOUCH_SELECTOR (sel3));
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (btns[3]), HILDON_TOUCH_SELECTOR (sel4));
 	
-	/*
-	gint i;
-	for(i=0;i<4;i++)
-		gtk_table_attach_defaults ( GTK_TABLE(conf_box), btns[i], i,i+1, 0,1 );
-	
-	for(i=0;i<4;i++)
-		gtk_table_attach_defaults ( GTK_TABLE(clr_box), clr[i], i,i+1, 1,2 );
-	
-	*/
 	gtk_box_pack_start(GTK_BOX(conf_box), btns[0], FALSE, TRUE, 1);
 	gtk_box_pack_start(GTK_BOX(conf_box), btns[1], FALSE, TRUE, 1);
 	gtk_box_pack_start(GTK_BOX(conf_box), btns[2], FALSE, TRUE, 1);
 	gtk_box_pack_start(GTK_BOX(conf_box), btns[3], FALSE, TRUE, 1);
-	/*gtk_table_attach_defaults ( GTK_TABLE(conf_box), clr1, 1,2, 0,1);
-	gtk_box_pack_start(GTK_BOX(clr_box), clr1, FALSE, TRUE, 1);
-	gtk_box_pack_start(GTK_BOX(clr_box), clr2, FALSE, TRUE, 1);
-	gtk_box_pack_start(GTK_BOX(clr_box), clr3, FALSE, TRUE, 1);
-	gtk_box_pack_start(GTK_BOX(clr_box), clr4, FALSE, TRUE, 1);
-*/
 
 	confirm = hildon_button_new(HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 	hildon_button_set_text ( HILDON_BUTTON(confirm), "Ok", NULL );
@@ -434,7 +403,6 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	gtk_box_pack_start ( GTK_BOX(action_box), confirm, FALSE,FALSE,0 );
 
 	gtk_box_pack_start ( GTK_BOX(main_box), conf_box, TRUE, TRUE, 1 );
-//	gtk_box_pack_start ( GTK_BOX(main_box), clr_box, TRUE, TRUE, 1 );
 	gtk_box_pack_start ( GTK_BOX(main_box), action_box, TRUE, FALSE, 1 );
 
 	gtk_container_add ( GTK_CONTAINER(window), main_box );
@@ -444,12 +412,7 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
                        g_strdup_printf("%s%s",GCONF_DIR,APP_NAME),
                        GCONF_CLIENT_PRELOAD_NONE,
                        NULL);
-/*
-	g_signal_connect ( G_OBJECT(sel1), "columns-changed", G_CALLBACK(set_shortcut), (gpointer)0 );
-	g_signal_connect ( G_OBJECT(sel2), "columns-changed", G_CALLBACK(set_shortcut), (gpointer)1 );	
-	g_signal_connect ( G_OBJECT(sel3), "columns-changed", G_CALLBACK(set_shortcut), (gpointer)2 );
-	g_signal_connect ( G_OBJECT(sel4), "columns-changed", G_CALLBACK(set_shortcut), (gpointer)3 );
-*/
+                       
 	g_signal_connect ( G_OBJECT(confirm), "clicked", G_CALLBACK(save_info), client );
 	
 	gtk_widget_set_sensitive ( GTK_WIDGET(confirm), FALSE );
@@ -458,12 +421,6 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	
 	parse_settings(client);
 
-	/*
-	for(i=0;i<4;i++) {
-		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel[i]), 0, -1);
-	        hildon_touch_selector_unselect_all (HILDON_TOUCH_SELECTOR(sel[i]), 0);
-	}
-	*/
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel1), 0, -1);
         hildon_touch_selector_unselect_all (HILDON_TOUCH_SELECTOR(sel1), 0);
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR(sel2), 0, -1);
