@@ -33,7 +33,7 @@ HD_DEFINE_PLUGIN_MODULE (QuickLaunchStatusMenuItem, quick_launch_status_menu_ite
 
 
 void
-parse_info (GConfClient* client)
+parse_info (GConfClient* client, gboolean big_icon)
 {
 	g_print("parsing info\n");
 	if ( client == NULL )
@@ -51,36 +51,19 @@ parse_info (GConfClient* client)
 			lst = gconf_client_get_list (GCONF_CLIENT(client),g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[i]), GCONF_VALUE_STRING, &err);
 			if ( lst != NULL ) {
 				in = g_slist_nth_data (lst, 1);
-				/*
-				 *  gdk_pixbuf_scale_simple         (const GdkPixbuf *src,
-				 *                                               int dest_width,
-				 *                                                                                            int dest_height,
-				 *                                                                                                                                         GdkInterpType interp_type);
-				 *
-				 *
-				 *
-				 * GdkPixbuf*  gdk_pixbuf_new_from_file        (const char *filename,
-				 *                                              GError **error);
-				 *
-				 *                                              
-				icoim = gtk_image_new_from_file( (gchar *)in );
-				gtk_widget_set_usize ( GTK_WIDGET(icoim), 48,48 );
 				
-				*/
 				g_print("getted = %s\n",in);
 				pixim = gdk_pixbuf_new_from_file ( (gchar *)in, NULL );
-				icoim = gtk_image_new_from_pixbuf (gdk_pixbuf_scale_simple ( pixim, 48,48, GDK_INTERP_BILINEAR ));
-//				gtk_widget_set_usize ( GTK_WIDGET(icoim), 48,48 );
+				if ( big_icon )
+					icoim = gtk_image_new_from_pixbuf (gdk_pixbuf_scale_simple (pixim, 64,64, GDK_INTERP_BILINEAR) );
+				else 
+					icoim = gtk_image_new_from_pixbuf (gdk_pixbuf_scale_simple ( pixim, 48,48, GDK_INTERP_BILINEAR ));
 				
 				if ( btns[i] == NULL )
 					g_print("btn failsk\n");
 				else g_print("btn ok'\n");
 				hildon_button_set_image ( HILDON_BUTTON(btns[i]), icoim );
 				gtk_widget_show ( GTK_WIDGET(btns[i]) );
-//				hildon_button_set_image_position (HILDON_BUTTON(btns[i]), GTK_POS_LEFT);
-//				hildon_button_set_alignment (HILDON_BUTTON(btns[i]), 0.0, 0.0, 0.0, 0.0);
-//				hildon_button_set_image_alignment (HILDON_BUTTON(btns[i]), 0.0, 0.0);
-//				hildon_button_set_image_position (HILDON_BUTTON(btns[i]), GTK_POS_LEFT);
 
 			}
 		}
@@ -218,7 +201,7 @@ quick_launch_status_menu_item_init (QuickLaunchStatusMenuItem *plugin)
                           NULL, NULL);
 
 
-	parse_info(client);
+	parse_info(client,FALSE);
 
 }
 
