@@ -3,8 +3,8 @@
 	
 	@author	Daniele Maio (b0unc3) 
 	@date	16/02/2010
-	@update 29/04/2010
-	@ver	0.5
+	@update 27/07/2010
+	@ver	0.6
 	
 */
 #ifndef __QUICK_LAUNCH_STATUS_MENU_ITEM_H__
@@ -51,6 +51,7 @@ GType quick_launch_status_menu_item_get_type (void);
 #define GCONF_DIR 	"/apps/Maemo/"
 #define APP_GCONF_KEY	GCONF_DIR"quicklaunch/"
 #define LOCALES_DIR	"/usr/share/locale"
+#define ICON_PATH 	"/usr/share/pixmaps/quicklaunch-search.png"
 
 
 static gchar 		*names[4];
@@ -63,11 +64,13 @@ static GtkWidget 	*confirm;
 static GtkWidget 	*window;
 static GtkWidget 	*shutter,*pkey;
 static GConfClient	*client;
-static HildonDialog 	*d;
+HildonDialog 		*d;
 gboolean 		previous_state; //true=open->close false=close->open
 
-void parse_info (GConfClient* client);
+void parse_info (GConfClient* client, gboolean big_icon);
 gboolean load_app(GtkWidget *widget , gpointer data);
+gboolean app_search_button_release(GtkWidget* widget, GdkEventButton *event);
+//gchar * app_search_search_retrive_app_name(GKeyFile* key_file);
 /**/
 
 G_END_DECLS
